###############################################################################################
###################        Reproducible-Research Script for               #####################
########    BRAF V600E mutant colorectal cancer subtypes based on gene expression    ##########
#                                                                                             #
# Figure 1 : Does not require R scripting                                                     #
# Figure 2 : Lines  120 to 292                                                                #
# Figure 3 : Lines  371 to 498 and 573 to 665                                                 #
# Figure 4 : Lines  721 to 769                                                                #
# Figure 5 : Survival data are not rendered public                                            #
# Supplementary Figure S1 : Lines 63 to 101                                                   #
# Supplementary Figure S2 : Lines 296 to 367                                                  #
# Supplementary Figure S3 : Lines 562 to 568                                                  #
# Supplementary Figure S4 : Same methods than in Figure 3C                                    #
# Supplementary Figure S5 : Lines 502 to 557                                                  #
# Supplementary Figure S6 : Lines 669 to 717                                                  #
# Supplementary Figure S7 : Lines 774 to 870                                                  #
# Supplementary Figure S8 : Lines 873 to 1007                                                 #
# Supplementary Figure S9 : Does not require R scripting                                      #  
# Supplementary Figure S10 : Lines 1012 to 1074                                               #
# Supplementary Figure S11 : Lines 1132 to 1273                                               #
# Table 1: Survival data are not rendered public                                              #
# Supplementary Table S1 : Does not require R scripting                                       #
# Supplementary Table S2 : Lines 1012 to 1074                                                 #
# Supplementary Table S3 : Lines 1276 to 1288                                                 #
# Supplementary Table S4 : Lines 1290 to 1318                                                 #
# Supplementary Table S5 : Does not require R scripting                                       #
# Supplementary Table S6 : Lines 1077 to 1129                                                 #
# Supplementary Table S7 : Lines 1133 to 1274                                                 #
# Supplementary movie : Lines 105 to 118                                                      #
###############################################################################################
stringsAsFactors=FALSE
#Load libraries
library(NMF)
library(nclust)
library(ggplot2)
library(glmnet)
library(limma)
library(VennDiagram)
library(matrixStats)
library(gridExtra)
library(RColorBrewer)
library(xtable)
library(gplots)
library(reshape2)
library(pheatmap)
library(pca3d)
library(rgl)
library(GEOquery)
library(sva)
library(liso)
library(tidyr)
library(Hmisc)

# Put the Reproducible_script directory here
setwd("YOURWORKINGDIRECTORYHERE")
dependecies_dir<-paste(getwd(),"/Dependencies",sep="")

#### LOAD BRAF mutant Dataset #####################################################
load(paste(dependecies_dir,"/BM_data.rda",sep=""))


######################################################################################################################
###########################################    Figure S1 Panel A    ##################################################
######################################################################################################################

colors<-c(rep("orange",365),rep("blue",752),rep("palegreen2",188),rep("red",208),rep("purple",76),rep("turquoise",566),rep("magenta",62),rep("black",59),rep("green",211))
colors<-c(rep("orange",length(which(merge_clin$Dataset=="TCGA"))),
          rep("blue",length(which(merge_clin$Dataset=="PETACC"))),
          rep("palegreen2",length(which(merge_clin$Dataset=="Agendia1"))),
          rep("red",length(which(merge_clin$Dataset=="Agendia2"))),
          rep("purple",length(which(merge_clin$Dataset=="Agendia3"))),
          rep("turquoise",length(which(merge_clin$Dataset=="French"))),
          rep("magenta",length(which(merge_clin$Dataset=="England"))),
          rep("black",length(which(merge_clin$Dataset=="Melbourne1"))),
          rep("green",length(which(merge_clin$Dataset=="Melbourne2"))))

PCA<-prcomp(t(combat_RNA))
#the three first principal components explian 80% of the variance
#PC1 vs PC2
par(mfrow=c(1,2),pty="s")
plot(PCA$x[,1],PCA$x[,2], type="n",xlab="Principal component 1",ylab="Principal component 2")
points(PCA$x[,1],PCA$x[,2],cex=.4,col=colors,pch=19)
#PC3 vs PC4
plot(PCA$x[,3],PCA$x[,4], type="n",xlab="Principal component 3",ylab="Principal component 4")
points(PCA$x[,3],PCA$x[,4],cex=.4,col=colors,pch=19)
#uncomment if you would like to plot legend
# legend("bottomleft",title="Dataset",col=unique(colors),
#        legend=c("TCGA","PETACC-3","Agendia (GSE42284)","Agendia (ICO)","Agendia (VHB)","Marisa et al. (GSE39582)","Schlicker et al. (GSE35896)","Melbourne1","Melbourne2"),
#        pch=16)



######################################################################################################################
###########################################    Figure S1 Panel B    ##################################################
######################################################################################################################

###Dendrogram
clustBRAF<-nclust2(t(combat_RNA))
dev.off()
plot(as.dendrogram(clustBRAF$rclust))



######################################################################################################################
###########################################    Supplementary movie    ################################################
######################################################################################################################

####3D PCA#####
pca3d(PCA,1:3,col=colors,
      title="Princpal component analysis: BRAF V600E mutant",new=T,
      show.scale = FALSE,
      show.pLine=FALSE)

movie3d(spin3d(axis=c(0,0.5,1)), duration=15, fps=10, movie = "PCA_BRAF",dir=getwd(),type = "gif")

rm(PCA,clustBRAF)
dev.off()

######################################################################################################################
###########################################     Figure 2 panel A      ################################################
######################################################################################################################

###PERFORM A NON-NEGATIVE MATRIX FACTORIZATION (NMF)######################
# there are only a few of negative values, therefore set them at 0, Create a matrix with negative values zeroed (called combat_RNA1)
combat_RNA1<-combat_RNA
for(i in 1:nrow(combat_RNA1)){
  for(j in 1:ncol(combat_RNA1)){
    if(combat_RNA1[i,j]<0){
      combat_RNA1[i,j]<-0
    }
  }
}

# Create a randomized matrix as negative control
V.random <-randomize(combat_RNA1)

# Uncomment the two following lines if you want to run the NMF on your own
# NMF_BRAFMUTANT<-nmf(combat_RNA1,2:6, nrun=200,.options="p16")
# NMF_Random <-nmf(V.random, 2:6, nrun=200,.options="p16")

# Alternatively, load the already created object containing the results of the NMF analysis
load(paste(dependecies_dir,"/NMF/NMF_ALLTEST.rda",sep=""))


#Left panel
consensusmap(NMF_BRAFMUTANT,annRow=NA,annCol=NA,color="Blues", info=FALSE)
consensusmap(NMF_Random,annRow=NA,annCol=NA,color="Blues", info=FALSE)

#Right panel
plot(NMF_BRAFMUTANT, NMF_Random)

rm(V.random,NMF_BRAFMUTANT,NMF_Random,combat_RNA1)



######################################################################################################################
###########################################     Figure 2 panel B      ################################################
######################################################################################################################

#NMF with more runs (500) for rank=2
# Uncomment the following line if you want to run the NMF on your own
# NMF_BRAFMUTANTREAL<-nmf(combat_RNA1,2,nrun=500,.options="p16")

# Alternatively, load the already created object containing the results of the NMF analysis
load(paste(dependecies_dir,"/NMF/NMF_ALLREAL.rda",sep=""))

#######PLOT REAL NMF######################################################
df<-data.frame("Location"=merge_clin$Site,"Gender"=merge_clin$Sex,"CMS_subtype"=merge_clin$CMS,"MSI_status"=merge_clin$MSI_status)
consensusmap(NMF_BRAFMUTANTREAL, annCol = df,
             main="BRAF V600E mutant NMF",
             annColors=list(c("green","purple","black"),
                            c("blue","pink"),
                            c("turquoise","red","pink","royalblue2","gray"),
                            c("orange","darkblue"),
                            c("black","grey"),
                            c("turquoise","pink")),labCol = NA, labRow = NA,color="Blues")
rm(df)

#Add the BM info to the clinical file
merge_clin$BM_subtype<-as.character(predict(NMF_BRAFMUTANTREAL))
merge_clin$BM_subtype[which(merge_clin$BM_subtype=="1")]<-"3"
merge_clin$BM_subtype[which(merge_clin$BM_subtype=="2")]<-"1"
merge_clin$BM_subtype[which(merge_clin$BM_subtype=="3")]<-"2"




######################################################################################################################
###########################################     Figure 2 panel E      ################################################
######################################################################################################################


Regr_table<-as.data.frame(matrix(nrow=nrow(combat_RNA),ncol=16))
colnames(Regr_table)<-c("Subtypes_coef","Subtype_t","Subtype_pval","Subtype_CI",
                        "MSI_coef","MSI_t","MSI_pval","MSI_CI",
                        "Site_coef","Site_t","Site_pval","Site_CI",
                        "Sex_coef","Sex_t","Sex_pval","Sex_CI")
rownames(Regr_table)<-rownames(combat_RNA)
merge_clinTEMP<-merge_clin
merge_clinTEMP$Site[which(merge_clinTEMP$Site=="Rectum")]<-"L"

for(i in 1:nrow(combat_RNA)){
  t<-lm(as.numeric(combat_RNA[i,])~ BM_subtype + MSI_status + Site + Sex, data=merge_clinTEMP)
  Regr_table[i,1]<-summary(t)$coefficients[2,1]
  Regr_table[i,5]<-summary(t)$coefficients[3,1]
  Regr_table[i,9]<-summary(t)$coefficients[4,1]
  Regr_table[i,13]<-summary(t)$coefficients[5,1]
  
  Regr_table[i,2]<-summary(t)$coefficients[2,3]
  Regr_table[i,6]<-summary(t)$coefficients[3,3]
  Regr_table[i,10]<-summary(t)$coefficients[4,3]
  Regr_table[i,14]<-summary(t)$coefficients[5,3]
  
  Regr_table[i,3]<-summary(t)$coefficients[2,4]
  Regr_table[i,7]<-summary(t)$coefficients[3,4]
  Regr_table[i,11]<-summary(t)$coefficients[4,4]
  Regr_table[i,15]<-summary(t)$coefficients[5,4]
  
  Regr_table[i,4]<-summary(t)$coefficients[2,2]
  Regr_table[i,8]<-summary(t)$coefficients[3,2]
  Regr_table[i,12]<-summary(t)$coefficients[4,2]
  Regr_table[i,16]<-summary(t)$coefficients[5,2]
  
  print(i)
}

#Selection of genes specific to BM subtype
pval<-0.00000005

genesUP<-rownames(Regr_table[which((Regr_table$Subtype_pval<pval)&
                                     (Regr_table$MSI_pval>pval)&
                                     (Regr_table$Site_pval>pval)&
                                     (Regr_table$Sex_pval>pval)&
                                     (Regr_table$Subtypes_coef>0)),])
genesDN<-rownames(Regr_table[which((Regr_table$Subtype_pval<pval)&
                                     (Regr_table$MSI_pval>pval)&
                                     (Regr_table$Site_pval>pval)&
                                     (Regr_table$Sex_pval>pval)&
                                     (Regr_table$Subtypes_coef<0)),])

#performs patient clustering within BM1 matrix
combat_S1<-rbind(combat_RNA[genesUP,which(merge_clin$BM_subtype==1)],
                 combat_RNA[genesDN,which(merge_clin$BM_subtype==1)])
clustS1<-nclust2(t(combat_S1))
combat_S1<-combat_S1[,clustS1$rclust$order]

#performs patient clustering within BM2 matrix
combat_S2<-rbind(combat_RNA[genesUP,which(merge_clin$BM_subtype==2)],
                 combat_RNA[genesDN,which(merge_clin$BM_subtype==2)])
clustS2<-nclust2(t(combat_S2))
combat_S2<-combat_S2[,clustS2$rclust$order]

combat_RNA_heatmap2<-cbind(combat_S1,combat_S2)

################# Heatmap of the right panel ##################
dev.off()
coldmap(as.matrix(combat_RNA_heatmap2),
        clab=colnames(combat_RNA_heatmap2),
        col.clab=c(rep("red",length(which(merge_clin$BM_subtyper==1))),rep("blue",length(which(merge_clin$BM_subtype==2)))),
        clust=NULL,
        rcenter=TRUE,
        corder=colnames(combat_RNA_heatmap2))

rm(combat_S1,combat_S2,clustS1,clustS2,combat_RNA_heatmap2)

################# Venn Diagram of the left panel ##################
total<-length(rownames(Regr_table[which(Regr_table$Subtype_pval<pval),]))
SubOnly<-length(rownames(Regr_table[which(Regr_table$Subtype_pval<pval),]))
MSIOnly<-length(rownames(Regr_table[which(Regr_table$MSI_pval<pval),]))
SiteOnly<-length(rownames(Regr_table[which(Regr_table$Site_pval<pval),]))
GenderOnly<-length(rownames(Regr_table[which(Regr_table$Sex_pval<pval),]))
SubMSI<-length(rownames(Regr_table[which((Regr_table$Subtype_pval<pval)&(Regr_table$MSI_pval<pval)&(Regr_table$Site_pval>pval)&(Regr_table$Sex_pval>pval)),]))
SubSite<-length(rownames(Regr_table[which((Regr_table$Subtype_pval<pval)&(Regr_table$MSI_pval>pval)&(Regr_table$Site_pval<pval)&(Regr_table$Sex_pval>pval)),]))
SubGender<-length(rownames(Regr_table[which((Regr_table$Subtype_pval<pval)&(Regr_table$MSI_pval>pval)&(Regr_table$Site_pval>pval)&(Regr_table$Sex_pval<pval)),]))
MSISite<-length(rownames(Regr_table[which((Regr_table$Subtype_pval>pval)&(Regr_table$MSI_pval<pval)&(Regr_table$Site_pval<pval)&(Regr_table$Sex_pval>pval)),]))
MSIGender<-length(rownames(Regr_table[which((Regr_table$Subtype_pval>pval)&(Regr_table$MSI_pval<pval)&(Regr_table$Site_pval>pval)&(Regr_table$Sex_pval<pval)),]))
SiteGender<-length(rownames(Regr_table[which((Regr_table$Subtype_pval>pval)&(Regr_table$MSI_pval>pval)&(Regr_table$Site_pval<pval)&(Regr_table$Sex_pval<pval)),]))
SubMSISite<-length(rownames(Regr_table[which((Regr_table$Subtype_pval<pval)&(Regr_table$MSI_pval<pval)&(Regr_table$Site_pval<pval)&(Regr_table$Sex_pval>pval)),]))
SubMSIGender<-length(rownames(Regr_table[which((Regr_table$Subtype_pval<pval)&(Regr_table$MSI_pval<pval)&(Regr_table$Site_pval>pval)&(Regr_table$Sex_pval<pval)),]))
SubSiteGender<-length(rownames(Regr_table[which((Regr_table$Subtype_pval<pval)&(Regr_table$MSI_pval>pval)&(Regr_table$Site_pval<pval)&(Regr_table$Sex_pval<pval)),]))
MSISiteGender<-length(rownames(Regr_table[which((Regr_table$Subtype_pval>pval)&(Regr_table$MSI_pval<pval)&(Regr_table$Site_pval<pval)&(Regr_table$Sex_pval<pval)),]))
SubMSISiteGender<-length(rownames(Regr_table[which((Regr_table$Subtype_pval<pval)&(Regr_table$MSI_pval<pval)&(Regr_table$Site_pval<pval)&(Regr_table$Sex_pval<pval)),]))

dev.off()

draw.quad.venn(SubOnly,MSIOnly,SiteOnly,GenderOnly,SubMSI,SubSite,SubGender,MSISite,MSIGender,SiteGender,
               SubMSISite,SubMSIGender,SubSiteGender,MSISiteGender,SubMSISiteGender,category=c("Subtype","MSI status","Site","Gender"),
               col=c("red","green","orange","blue"),
               fill=c("tomato","skyblue","darkolivegreen1","tan1"),
               alpha=c(rep(0.3,4)),cex=c(rep(1.6,15)),cat.cex=c(rep(1.6,4)))
rm(total,SubOnly,MSIOnly,SiteOnly,GenderOnly,SubMSI,SubSite,SubGender,MSISite,MSIGender,SiteGender,SubMSISite,SubMSIGender,SubSiteGender,MSISiteGender,SubMSISiteGender)



######################################################################################################################
###########################################    Figure S2 Panel A    ##################################################
######################################################################################################################

#Double hierarchical clustering
clustBMut<-nclust2(t(combat_RNA))

#Heatmap
coldmap(t(combat_RNA),
        clust=clustBMut,
        rlab=list(colnames(combat_RNA)),
        rannot=list(cbind("BM_subtype"=c("red","blue")[as.numeric(factor(merge_clin$BM_subtype))],
                          " "=c("red","blue")[as.numeric(factor(merge_clin$BM_subtype))])))
rm(clustBMut)


######################################################################################################################
###########################################    Figure S2 Panel B    ##################################################
######################################################################################################################

#Split MSI and MSS matrices
MSI_combat<-combat_RNA[,which(merge_clin$MSI_status=="MSI")]
MSS_combat<-combat_RNA[,which(merge_clin$MSI_status=="MSS")]

#scale every gene to 0 in both datasets
MSI_combat_scaled<-MSI_combat-apply(MSI_combat,1,function(x){mean(x)})
MSS_combat_scaled<-MSS_combat-apply(MSS_combat,1,function(x){mean(x)})

#And reput together the matrices
Supervised_combat<-cbind(MSI_combat_scaled,MSS_combat_scaled)
merge_clin_MSI<-merge_clin[which(merge_clin$ID %in% colnames(Supervised_combat)),]

#Add the mean of gene expression in the original matrix to reach similar level of expression (in order to being able to compare NMF calls)
meanToAdd<-mean(as.matrix(combat_RNA))
Supervised_combat<-Supervised_combat+meanToAdd

############# NMF ##################################################
#Process negative values
Supervised_combat1<-Supervised_combat
for(i in 1:nrow(Supervised_combat1)){
  for(j in 1:ncol(Supervised_combat1)){
    if(Supervised_combat1[i,j]<0){
      Supervised_combat1[i,j]<-0
    }
  }
}

#Uncomment if you want to run the NMF on your own
# NMF_MSI<-nmf(Supervised_combat1,2, nrun=500,.options="p16")

#Alternatively, you can load it from the Dependencies folder
load(paste(dependecies_dir,"/NMF/NMF_MSI.rda",sep=""))

#Compare calls with original calls
whichCluster_supervised<-as.character(predict(NMF_MSI))
whichCluster_supervised[which(whichCluster_supervised=="1")]<-"3"
whichCluster_supervised[which(whichCluster_supervised=="2")]<-"1"
whichCluster_supervised[which(whichCluster_supervised=="3")]<-"2"
names(whichCluster_supervised)<-colnames(NMF_MSI)
idx<-match(merge_clin_MSI$ID,names(whichCluster_supervised))
merge_clin_MSI$Cluster_Supervised<-whichCluster_supervised[idx]

#Put the two different calls in a table and do the mosaic plot
df<-data.frame("BM_Subtypes"=merge_clin_MSI$BM_subtype,"BM_MSI_Subtypes"=merge_clin_MSI$Cluster_Supervised)
mosaicplot(table(df),color=c("red","blue"))

#Cohen Kappa
library(psych)
cohen.kappa(matrix(c(51,9,6,125),nrow=2))

rm(MSI_combat,MSI_combat_scaled,MSS_combat,MSS_combat_scaled,Supervised_combat,Supervised_combat1,df,merge_clinTEMP,
   NMF_BRAFMUTANTREAL,NMF_MSI,merge_clin_MSI)



######################################################################################################################
#########################################       Figure 3A      #######################################################
######################################################################################################################

################## GSEA ANALYSIS ####################

#Create GCT file for input in genepattern for GSEA and ssGSEA
combat_BM1<-combat_RNA[,which(merge_clin$BM_subtype=="1")]
combat_BM2<-combat_RNA[,which(merge_clin$BM_subtype=="2")]

combatGSEA<-cbind(combat_BM1,combat_BM2)
combatGSEA_reduced<-combatGSEA[which(rownames(combatGSEA) %in% c(genesDN,genesUP)),]

# For GSEA, transform the Gene symbol into Affy probes because GSEA in GenePattern doesn't accept HUGO gene symbol (select HG_U133_Plus_2.chip in GenePattern)
# For ssGSEA, let the matrix in Gene Symbol

gpl<-getGEO("GPL570")
gpl1<-Table(gpl)
rownames(combatGSEA)<-gpl1$ID[match(rownames(combatGSEA),gpl1$"Gene Symbol")]
rownames(combatGSEA_reduced)<-gpl1$ID[match(rownames(combatGSEA_reduced),gpl1$"Gene Symbol")]

#Function to transform an expression matrix into GCT format that is required by the Broad
transformIntoGCT<-function(MATRIX){
  nsamples<-ncol(MATRIX)
  ngenes<-nrow(MATRIX)
  MATRIX$NAME<-rownames(MATRIX)
  MATRIX$Description<-rownames(MATRIX)
  MATRIX<-MATRIX[,c(grep("NAME",colnames(MATRIX)),grep("Description",colnames(MATRIX)),1:nsamples)]  
  info<-colnames(MATRIX)
  TMP<-as.data.frame(matrix(nrow=3,ncol=(nsamples+2)))
  TMP[1,]<-c("#1.2",rep("",(nsamples+1)))
  TMP[2,]<-c(ngenes,nsamples,rep("",nsamples))
  TMP[3,]<-info
  colnames(MATRIX)<-colnames(TMP)
  TMP2<-rbind(TMP,MATRIX)
  rownames(TMP2)<-NULL
  MATRIX<-TMP2
  return(MATRIX)
}

combatGSEA<-transformIntoGCT(combatGSEA)
combatGSEA_reduced<-transformIntoGCT(combatGSEA_reduced)

rm(gpl,gpl1)

# #Uncomment if you want to save the GCT file
# write.table(combatGSEA,file="./BM.gct",
#             quote = FALSE,
#             col.names = FALSE,
#             row.names = FALSE,
#             sep="\t")
# write.table(combatGSEA_reduced,file="./BM_reduced.gct",
#             quote = FALSE,
#             col.names = FALSE,
#             row.names = FALSE,
#             sep="\t")

#Create the CLS phenotype file for both BM.gct and BM_reduced.gct
CLS<-as.data.frame(matrix(nrow=3,ncol=ncol(combat_RNA)))
CLS[1,]<-c(ncol(combat_RNA),"2","1",rep("",215))
CLS[2,]<-c("#","BM1","BM2",rep("",215))
CLS[3,]<-c(rep(0,length(which(merge_clin$BM_subtype=="1"))),rep(1,length(which(merge_clin$BM_subtype=="2"))))

#Uncomment if you want to save the CLS file
# write.table(CLS,file="./CLS.cls",
#             quote = FALSE,
#             col.names = FALSE,
#             row.names = FALSE)


#Run the ssGSEA on GenePattern then save the output.gct file (you can also load it directly from the Dependencies folder)
###ssGSEA results analyses
ssGSEA_red<-read.delim(paste(dependecies_dir,"/ssGSEA/ssGSEA_BM1_BM2_reduced.gct",sep=""),sep="\t",header=T,row.names=1,skip=2)[,-1]
ssGSEA<-read.delim(paste(dependecies_dir,"/ssGSEA/ssGSEA_BM1_BM2.gct",sep=""),sep="\t",header=T,row.names=1,skip=2)[,-1]


#Differential expression analysis of the ssGSEA scores

vec<-c(rep(0,length(which(merge_clin$BM_subtype=="1"))),rep(1,length(which(merge_clin$BM_subtype=="2"))))
design<-model.matrix(~vec)
fit <- lmFit(object=ssGSEA,design=design);fit_red <- lmFit(object=ssGSEA_red,design=design)
fit1 <- eBayes(fit);fit1_red <- eBayes(fit_red)
DE_S1S2 <-topTable(fit1, coef = 2, adjust = "fdr",number=nrow(ssGSEA))
DE_S1S2_red <-topTable(fit1_red, coef = 2, adjust = "fdr",number=nrow(ssGSEA_red))

#Select and reorder the processes that are differentially represented
DE_S1S2UP<-DE_S1S2_red[which((DE_S1S2_red$adj.P.Val<0.00000000001)&(DE_S1S2_red$logFC>0)),]
ssGSEAUP<-ssGSEA_red[match(rownames(DE_S1S2UP),rownames(ssGSEA_red)),]

DE_S1S2DN<-DE_S1S2_red[which((DE_S1S2_red$adj.P.Val<0.00000000001)&(DE_S1S2_red$logFC<0)),]
ssGSEADN<-ssGSEA_red[match(rownames(DE_S1S2DN),rownames(ssGSEA_red)),]

ssGSEA_heatmap<-rbind(ssGSEAUP,ssGSEADN);rm(ssGSEAUP,ssGSEADN)
rownames(ssGSEA_heatmap)<-sapply(rownames(ssGSEA_heatmap),function(x){strsplit(x,split="HALLMARK_")[[1]][2]})

#Draw the heatmap

my.breaks <- c(seq(-3, -1, length.out=10),seq(-0.999999, 0.9999999, length.out=100),seq(1,3, length.out=10))
heatmap.2(as.matrix(ssGSEA_heatmap),
          Rowv=FALSE,
          Colv=FALSE,
          dendrogram="none",
          scale="row",
          trace="none",
          col=colorRampPalette(c("blue4","black","gold"))(119),
          breaks=my.breaks,
          ColSideColors=c(rep("red",length(which(merge_clin$BM_subtype==1))),rep("blue",length(which(merge_clin$BM_subtype==2)))),
          key=FALSE)



######################################################################################################################
#########################################       Figure 3B      #######################################################
######################################################################################################################

# Load this file which is the results of ssGSEA for BM1, BM2, a subset of KRAS mut and WT2 patients with the reduced list of genes
COMP_ALL<-read.csv(paste(dependecies_dir,"/ssGSEA/ssGSEA_red.csv",sep=""),row.names=1)
Heat<-as.data.frame(matrix(nrow=nrow(COMP_ALL),ncol=4))
rownames(Heat)<-sapply(rownames(COMP_ALL),function(x){strsplit(x,split="HALLMARK_")[[1]][2]})
colnames(Heat)<-c("BM1","BM2","WT2","KMUT")
Heat$WT2<-apply(COMP_ALL[,1:149],1,mean)
Heat$BM2<-apply(COMP_ALL[,150:298],1,mean)
Heat$KMUT<-apply(COMP_ALL[,299:367],1,mean)
Heat$BM1<-apply(COMP_ALL[,368:436],1,mean)
Heat<-Heat[,c(1,3,4,2)]
pheatmap(Heat,scale="row",cluster_cols=F,color=colorRampPalette(c("white","red"))(119))

#The p-value heatmap is drawn under Figure S5 code



######################################################################################################################
#########################################       Figure S5      #######################################################
######################################################################################################################

# Load this file which is the results of ssGSEA for BM1, BM2, a subset of KRAS mut and WT2 patients with the whole list of genes
COMP_ALL<-read.csv(paste(dependecies_dir,"/ssGSEA/ssGSEA.csv",sep=""),row.names=1)
Heat<-as.data.frame(matrix(nrow=nrow(COMP_ALL),ncol=4))
rownames(Heat)<-sapply(rownames(COMP_ALL),function(x){strsplit(x,split="HALLMARK_")[[1]][2]})
colnames(Heat)<-c("BM1","BM2","WT2","KMUT")
Heat$WT2<-apply(COMP_ALL[,1:149],1,mean)
Heat$BM2<-apply(COMP_ALL[,150:298],1,mean)
Heat$KMUT<-apply(COMP_ALL[,299:367],1,mean)
Heat$BM1<-apply(COMP_ALL[,368:436],1,mean)
Heat<-Heat[,c(1,3,4,2)]
pheatmap(Heat,scale="row",cluster_cols=F,color=colorRampPalette(c("white","red"))(119))

#Heatmap of logpvalue for both reduced and non-reduced (ALSO used in Figure 3B)
Modules<-merge(DE_S1S2,DE_S1S2_red,by="row.names",all=T)
Modules_GO<-data.frame("Term"=Modules$Row.names,
                       "FC_all"=Modules$logFC.x,
                       "Whole_list"=Modules$adj.P.Val.x,
                       "FC_reduced"=Modules$t.y,
                       "Reduced_list"=Modules$adj.P.Val.y)
Modules_GO$FC_reduced[which(is.na(Modules_GO$FC_reduced))]<-0
Modules_GO$Reduced_list[which(is.na(Modules_GO$Reduced_list))]<-1

Heat<-as.data.frame(matrix(0,ncol=nrow(DE_S1S2),nrow=2))
colnames(Heat)<-rownames(DE_S1S2);rownames(Heat)<-c("Whole_list","Reduced_list")
for(i in 1:ncol(Heat)){
  for(j in 1:nrow(Modules_GO)){
    if(colnames(Heat)[i]==Modules_GO$Term[j]){
      nrow<-match(Modules_GO[j,2],rownames(Heat))
      if(Modules_GO[j,2]>=0){
        Heat[1,i]<-(-(log10(as.numeric(Modules_GO[j,3]))))
      }
      if(Modules_GO[j,4]>0){
        Heat[2,i]<-(-(log10(as.numeric(Modules_GO[j,5]))))
      }
      if(Modules_GO[j,2]<=0){
        Heat[1,i]<-(log10(as.numeric(Modules_GO[j,3])))
      }
      if(Modules_GO[j,4]<0){
        Heat[2,i]<-(log10(as.numeric(Modules_GO[j,5])))
      }
      
    }
  }
}

names<-rownames(Heat)
Heat<-apply(Heat,2,function(x) as.numeric(x))
rownames(Heat)<-names
Heat<-Heat[,order(Heat[2,])]
my.breaks <- c(seq(min(Heat), -0.00001, length.out=100),0,seq(0.00001,max(Heat), length.out=100))
pheatmap(as.matrix(Heat),color = colorRampPalette(c("darkgreen","white","red"))(201),cluster_rows=F,cluster_cols=F,main="GSEA",legend=T,
         breaks=my.breaks)




######################################################################################################################
#########################################       Figure S3      #######################################################
######################################################################################################################

# Go in GenePattern, load the GCT, the CLS, chose the signature you want (Hallmark in this case)
# select the chip (HG_U133_Plus_2.chip), run it and save the results
# The Figures are included in the result folder




######################################################################################################################
#########################################       Figure 3C      #######################################################
######################################################################################################################

####The ssGSEA was run for a subset of signatures indicated in the paper and the results can be loaded###################
ssGSEA_biased<-read.csv(paste(dependecies_dir,"/ssGSEA/ssGSEA_supervised.csv",sep=""),header=T,row.names=1)

############  KRAS heatmap  ##############
TEMP<-ssGSEA_biased[grep("KRAS",rownames(ssGSEA_biased)),]
GSEAS1<-TEMP[,1:69];clus1<-nclust2(t(GSEAS1));GSEAS1<-GSEAS1[,clus1$rclust$order]
GSEAS2<-TEMP[,70:218];clus2<-nclust2(t(GSEAS2));GSEAS2<-GSEAS2[,clus2$rclust$order]
TEMP<-cbind(GSEAS1,GSEAS2)

TEMP<-TEMP[-3,]
TEMP<-TEMP[c(1,2,3,5,4),]
my.breaks <- c(seq(-3, -1, length.out=10),seq(-0.999999, 0.9999999, length.out=100),seq(1,3, length.out=10))
heatmap.2(as.matrix(TEMP),Rowv=FALSE,Colv=FALSE,dendrogram="none",scale="row",trace="none",
          col=colorRampPalette(c("blue4","black","gold"))(119),breaks=my.breaks,
          ColSideColors=c(rep("red",length(which(merge_clin$BM_subtype==1))),rep("blue",length(which(merge_clin$BM_subtype==2)))),key=F)

############  CELL CYCLE  ##############
TEMP<-ssGSEA_biased[grep("CYCLE",rownames(ssGSEA_biased)),]
TEMP1<-ssGSEA_biased[grep("E2F",rownames(ssGSEA_biased)),]
TEMP2<-ssGSEA_biased[grep("G2M",rownames(ssGSEA_biased)),]

TEMP<-rbind(TEMP,TEMP1,TEMP2)
GSEAS1<-TEMP[,1:69];clus1<-nclust2(t(GSEAS1));GSEAS1<-GSEAS1[,clus1$rclust$order]
GSEAS2<-TEMP[,70:218];clus2<-nclust2(t(GSEAS2));GSEAS2<-GSEAS2[,clus2$rclust$order]
TEMP<-cbind(GSEAS1,GSEAS2)

TEMP<-TEMP[c(8,2,1,3,4,5,6,7,9),]
my.breaks <- c(seq(-3, -1, length.out=10),seq(-0.999999, 0.9999999, length.out=100),seq(1,3, length.out=10))
heatmap.2(as.matrix(TEMP),Rowv=FALSE,Colv=FALSE,dendrogram="none",scale="row",trace="none",
          col=colorRampPalette(c("blue4","black","gold"))(119),breaks=my.breaks,
          ColSideColors=c(rep("red",length(which(merge_clin$BM_subtype==1))),rep("blue",length(which(merge_clin$BM_subtype==2)))),key=F)

############  EMT  ##############
TEMP<-ssGSEA_biased[grep("EPITHELIAL",rownames(ssGSEA_biased)),]
TEMP1<-ssGSEA_biased[grep("EMT",rownames(ssGSEA_biased)),]

TEMP<-rbind(TEMP,TEMP1)
GSEAS1<-TEMP[,1:69];clus1<-nclust2(t(GSEAS1));GSEAS1<-GSEAS1[,clus1$rclust$order]
GSEAS2<-TEMP[,70:218];clus2<-nclust2(t(GSEAS2));GSEAS2<-GSEAS2[,clus2$rclust$order]
TEMP<-cbind(GSEAS1,GSEAS2)

my.breaks <- c(seq(-3, -1, length.out=10),seq(-0.999999, 0.9999999, length.out=100),seq(1,3, length.out=10))
heatmap.2(as.matrix(TEMP),Rowv=FALSE,Colv=FALSE,dendrogram="none",scale="row",trace="none",
          col=colorRampPalette(c("blue4","black","gold"))(119),breaks=my.breaks,
          ColSideColors=c(rep("red",length(which(merge_clin$BM_subtype==1))),rep("blue",length(which(merge_clin$BM_subtype==2)))),key=F)

############  WNT heatmap  ##############
TEMP<-ssGSEA_biased[grep("WNT",rownames(ssGSEA_biased)),]

GSEAS1<-TEMP[,1:69];clus1<-nclust2(t(GSEAS1));GSEAS1<-GSEAS1[,clus1$rclust$order]
GSEAS2<-TEMP[,70:218];clus2<-nclust2(t(GSEAS2));GSEAS2<-GSEAS2[,clus2$rclust$order]
TEMP<-cbind(GSEAS1,GSEAS2)

my.breaks <- c(seq(-3, -1, length.out=10),seq(-0.999999, 0.9999999, length.out=100),seq(1,3, length.out=10))
heatmap.2(as.matrix(TEMP),Rowv=FALSE,Colv=FALSE,dendrogram="none",scale="row",trace="none",
          col=colorRampPalette(c("blue4","black","gold"))(119),breaks=my.breaks,
          ColSideColors=c(rep("red",length(which(merge_clin$BM_subtype==1))),rep("blue",length(which(merge_clin$BM_subtype==2)))),key=F)

############  EGFR heatmap  ##############
TEMP<-ssGSEA_biased[grep("EGFR",rownames(ssGSEA_biased)),]

GSEAS1<-TEMP[,1:69];clus1<-nclust2(t(GSEAS1));GSEAS1<-GSEAS1[,clus1$rclust$order]
GSEAS2<-TEMP[,70:218];clus2<-nclust2(t(GSEAS2));GSEAS2<-GSEAS2[,clus2$rclust$order]
TEMP<-cbind(GSEAS1,GSEAS2)

my.breaks <- c(seq(-3, -1, length.out=10),seq(-0.999999, 0.9999999, length.out=100),seq(1,3, length.out=10))
heatmap.2(as.matrix(TEMP),Rowv=FALSE,Colv=FALSE,dendrogram="none",scale="row",trace="none",
          col=colorRampPalette(c("blue4","black","gold"))(119),breaks=my.breaks,
          ColSideColors=c(rep("red",length(which(merge_clin$BM_subtype==1))),rep("blue",length(which(merge_clin$BM_subtype==2)))),key=F)

############  MTOR heatmap  ##############
TEMP<-ssGSEA_biased[grep("MTOR",rownames(ssGSEA_biased)),]
TEMP1<-ssGSEA_biased[grep("4EBP",rownames(ssGSEA_biased)),]
TEMP<-rbind(TEMP,TEMP1)

GSEAS1<-TEMP[,1:69];clus1<-nclust2(t(GSEAS1));GSEAS1<-GSEAS1[,clus1$rclust$order]
GSEAS2<-TEMP[,70:218];clus2<-nclust2(t(GSEAS2));GSEAS2<-GSEAS2[,clus2$rclust$order]
TEMP<-cbind(GSEAS1,GSEAS2)

TEMP<-TEMP[c(2,3,1,4),]
TEMP<-TEMP[-3,]
my.breaks <- c(seq(-3, -1, length.out=10),seq(-0.999999, 0.9999999, length.out=100),seq(1,3, length.out=10))
heatmap.2(as.matrix(TEMP),Rowv=FALSE,Colv=FALSE,dendrogram="none",scale="row",trace="none",
          col=colorRampPalette(c("blue4","black","gold"))(119),breaks=my.breaks,
          ColSideColors=c(rep("red",length(which(merge_clin$BM_subtype==1))),rep("blue",length(which(merge_clin$BM_subtype==2)))),key=F)

rm(TEMP,TEMP1,TEMP2,GSEAS1,GSEAS2,my.breaks,COMP_ALL,DE_S1S2,DE_S1S2DN,DE_S1S2_red,DE_S1S2UP,Heat,Modules,Modules_GO,
   combatGSEA,combat_BM1,combat_BM2,design,ssGSEA,ssGSEA_biased,ssGSEA_heatmap,ssGSEA_red,fit,fit1,fit1_red,fit_red,
   clus1,clus2,)



######################################################################################################################
#########################################       Figure S6      #######################################################
######################################################################################################################

#Check for signature overlap
GMX<-read.csv(paste(dependecies_dir,"/ssGSEA/Signatures_used.csv",sep=""),header=TRUE,sep=",",skip=1)
#KRAS
KRAS_sig <- list("M2878" = GMX$M2878[which(GMX$M2878 != "")],
                 "M2882" = GMX$M2882[which(GMX$M2882 != "")],
                 "M5953" = GMX$M5953[which(GMX$M5953 != "")],
                 "M10573" = GMX$M10573[which(GMX$M10573 != "")],
                 "M5956" = GMX$M5956[which(GMX$M5956 != "")])
venn(KRAS_sig)
title("KRAS signatures")

#Cell cycle
CC_sig1 <- list("M1484" = GMX$M1484[which(GMX$M1484 != "")],
                "M12829" = GMX$M12829[which(GMX$M12829 != "")],
                "M1396" = GMX$M1396[which(GMX$M1396 != "")],
                "M543" = GMX$M543[which(GMX$M543 != "")],
                "M14894" = GMX$M14894[which(GMX$M14894 != "")])

CC_sig2<-list("M8627" = GMX$M8627[which(GMX$M8627 != "")],
              "M2632" = GMX$M2632[which(GMX$M2632 != "")],
              "M5925" = GMX$M5925[which(GMX$M5925 != "")],
              "M5901" = GMX$M5901[which(GMX$M5901 != "")])
venn(CC_sig1)
venn(CC_sig2)
title("Cell cycle signatures")

#EMT
EMT_sig <- list("M11513" = GMX$M11513[which(GMX$M11513 != "")],
                "M1417" = GMX$M1417[which(GMX$M1417 != "")],
                "M5930" = GMX$M5930[which(GMX$M5930 != "")],
                "M8191" = GMX$M8191[which(GMX$M8191 != "")],
                "M5915" = GMX$M5915[which(GMX$M5915 != "")])

venn(EMT_sig)
title("EMT signatures")

#MTORC1
MTOR_sig <- list("M5924" = GMX$M5924[which(GMX$M5924 != "")],
                 "M7561" = GMX$M7561[which(GMX$M7561 != "")],
                 "M16909" = GMX$M16909[which(GMX$M16909 != "")],
                 "M1919" = GMX$M1919[which(GMX$M1919 != "")])

venn(MTOR_sig)
title("MTORC signatures")
rm(GMX,KRAS_sig,CC_sig1,CC_sig2,EMT_sig,MTOR_sig)



######################################################################################################################
#########################################       Figure 4      ########################################################
######################################################################################################################

#Load the Proteomics and phosphoproteomics data for TCGA
Phospho_X<-read.table(paste(dependecies_dir,"/Proteomics/TCGA-COAD-L3-S42.csv",sep=""),header=TRUE,sep=",")
Phospho_X<-t(Phospho_X);Phospho_X<-Phospho_X[-2,];colnames(Phospho_X)<-Phospho_X[1,];Phospho_X<-Phospho_X[-1,]

#Extract TCGA patient names which are BM1 and BM2
TCGA_S1<-as.character(merge_clin$ID[which((merge_clin$Dataset=="TCGA")&(merge_clin$BM_subtype==1))])
TCGA_S2<-as.character(merge_clin$ID[which((merge_clin$Dataset=="TCGA")&(merge_clin$BM_subtype==2))])

#Create the Matrix for the BM patients only
Phospho_X<-as.matrix(cbind(Phospho_X[,which(colnames(Phospho_X) %in% TCGA_S1)],
                           Phospho_X[,which(colnames(Phospho_X) %in% TCGA_S2)]))
ProtNames<-rownames(Phospho_X)
Phospho_X<-apply(Phospho_X,2,as.numeric)
rownames(Phospho_X)<-ProtNames

#DE expression and selection of those with p-value under 0.05
vec<-c(rep(0,length(which(colnames(Phospho_X) %in% TCGA_S1))),rep(1,length(which(colnames(Phospho_X) %in% TCGA_S2))))
design<-model.matrix(~vec)
DE_Phospho <- lmFit(object=Phospho_X,design=design)
DE_Phospho <- eBayes(DE_Phospho)
DE_Phospho <-topTable(DE_Phospho, coef = 2, adjust = "fdr",number=nrow(Phospho_X))
DE_Phospho <-DE_Phospho[which(DE_Phospho$P.Value < 0.05),]

#Matrix with only DE genes
Phospho_X<-Phospho_X[which(rownames(Phospho_X) %in% rownames(DE_Phospho)),]

#Clustering and ordering
clust_Phospho<-nclust2(t(Phospho_X))
Phospho_X<-Phospho_X[clust_Phospho$cclust$order,]


my.breaks <- c(seq(-4, -2, length.out=5),seq(-1.999999, 1.9999999, length.out=1000),seq(2,4, length.out=5))
heatmap.2(as.matrix(Phospho_X),
          Rowv=FALSE,
          Colv=FALSE,
          dendrogram="none",
          scale="row",
          trace="none",
          col=bluered(1009),
          ColSideColors=c(rep("red",6),rep("blue",21)),
          breaks=my.breaks,
          colsep=6,
          key=F)

rm(Phospho_X,TCGA_S1,TCGA_S2,ProtNames,vec,design,DE_Phospho,clust_Phospho,my.breaks)




######################################################################################################################
#########################################       Figure S7      #######################################################
######################################################################################################################

############ CIBERSORT ##################
CIBERSORT_X<-cbind(combat_RNA[,which(merge_clin$BM_subtype==1)],combat_RNA[,which(merge_clin$BM_subtype==2)])

# Download the CIBERSORT.R script and LM22.txt from https://cibersort.stanford.edu/ , and paste them in the Dependencies folder
# Go to Line 120 of the CIBERSORT.R script and make the following change: 
# Y <- read.table(mixture_file, header=T, sep="\t", row.names=1,check.names=F) 
# should be replaced by:
# Y <- mixture_file
source(paste(dependecies_dir,"/CIBERSORT.R",sep=""))

#Run CIBERSORT
Cib_BM<-CIBERSORT(paste(dependecies_dir,"/LM22.txt",sep=""),CIBERSORT_X, perm=100, QN=F)

#Format the results in order to make a stacked histogram

Stack<-melt(Cib_BM[,1:22])
colnames(Stack)<-c("X1","X2","value")
Stack$X2 <- factor(Stack$X2,levels=rev(colnames(Cib_BM)[1:22]))
Stack$X1 <- factor(Stack$X1,levels=rownames(Cib_BM))
Colors<-c("khaki1","khaki3","khaki4","goldenrod","darkorange3","burlywood1","darkgoldenrod",
          "chartreuse2","chartreuse3","chartreuse4","cornflowerblue","dodgerblue4","mediumpurple1","mediumpurple4",
          "red1","red3","red4","snow1","snow2","snow3","snow4","black")

ggplot(Stack, aes(x = X1, y = value,fill=X2,order = -as.numeric(X2))) +
  geom_bar(stat='identity') +
  scale_fill_manual(values=rev(Colors)) +
  ylab("Relative Percent") +
  xlab("Patients")+ guides(fill=guide_legend(title="Immune component")) +
  theme_bw()

DECib<-t(Cib_BM[,1:22])
vec<-c(rep(0,69),rep(1,149))
design<-model.matrix(~vec)
DE_Ciber <- lmFit(object=DECib,design=design)
DE_Ciber <- eBayes(DE_Ciber)
DE_Ciber_res <-topTable(DE_Ciber, coef = 2, adjust = "fdr",number=nrow(DECib))
DE_Ciber_res <-DE_Ciber_res[which(DE_Ciber_res$adj.P.Val < 0.05),]
TypetobeKept<-rownames(DE_Ciber_res)

Stack_TMP<-Stack[which(Stack$X2 %in% TypetobeKept),]
Stack_TMP$BM<-merge_clin$BM_subtype[match(Stack_TMP$X1,merge_clin$ID)]


##############  Make the boxplots for relative percentages #############
ggplot(Stack_TMP, aes(x = BM, y = value)) +
  geom_boxplot(aes(fill=BM)) +
  geom_jitter(aes(fill=BM), size=1.5, position = position_jitter(width = .3)) +
  facet_wrap( ~ X2, scales="free") +
  scale_fill_manual(values=c("red","blue"), 
                    name="BM subtypes",
                    labels=c("BM1", "BM2")) +
  scale_x_discrete(labels=NULL) +
  ylab("Relative Percentage")

rm(CIBERSORT_X,Cib_BM,Stack,Colors,DECib,vec,design,DE_Ciber,DE_Ciber_res)

############## Heatmap of Macrophages genes ###############

#Load macrophages genes
load(paste(dependecies_dir,"/Macrophage_genes.rda",sep=""))


Macrophage_X<-combat_RNA[which(rownames(combat_RNA) %in% Macrophage_genes),c(which(merge_clin$BM_subtype==1),which(merge_clin$BM_subtype==2))]
Macrophage_clin<-merge_clin[c(which(merge_clin$BM_subtype==1),which(merge_clin$BM_subtype==2)),]
Macrophage_clin$Annot<-NA;Macrophage_clin$Annot[which(Macrophage_clin$BM_subtype==1)]<-"BM1";Macrophage_clin$Annot[which(Macrophage_clin$BM_subtype==2)]<-"BM2"

##Creating Annotation tables
annotation_col_P1 <- data.frame("BM"=as.factor(Macrophage_clin$Annot),
                                "MSI"=as.factor(Macrophage_clin$MSI_status))
rownames(annotation_col_P1) = colnames(Macrophage_X)
ann_colors_P1 = list(BM = c(BM1="red", BM2="blue"),MSI = c(MSI="orange",MSS="darkblue"))

#Function to control the dendrogram ordering
callback = function(hc, mat){
  sv = svd(t(mat))$v[,1]
  dend = reorder(as.dendrogram(hc), wts = sv)
  as.hclust(dend)
}

#Computing of non-linear breaks and colors
z_score<-t(apply(Macrophage_X,1,function(x) scale(x,center=T,scale=F))) / apply(t(apply(Macrophage_X,1,function(x) scale(x,center=T,scale=F))),1,sd)
breaks<-c(seq(-5,-1,length.out =5),seq(-0.9999,0.9999,length.out=100),seq(1,5,length.out =5))
breaks<-c(seq(min(z_score),(min(z_score)+((max(z_score)-min(z_score))*0.4)+0.0001),length.out =100/5),
          seq((min(z_score)+(max(z_score)-min(z_score))*0.4),(max(z_score)-(max(z_score)-min(z_score))*0.4),length.out =((3*100)/5)+1),
          seq((max(z_score)-((max(z_score)-min(z_score))*0.4)+0.0001),max(z_score),length.out =100/5))

#Draw heatmap
pheatmap(Macrophage_X,cluster_rows = T,cluster_cols = F,annotation_col=annotation_col_P1,annotation_colors = ann_colors_P1,
         color = colorRampPalette(c("turquoise", "black", "orange"))(109),border_color="black",
         show_colnames=F,main="Macrophage",scale="row",annotation_legend=F,cellheight=12,
         treeheight_row=20,clustering_callback=callback,breaks=breaks)

rm(Macrophage_clin,Macrophage_genes,Macrophage_X,ann_colors_P1,annotation_col_P1,z_score,breaks)


######################################################################################################################
#########################################       Figure S8      #######################################################
######################################################################################################################
# Methylation data are too big to be provided in this reproducible script, thus the data provided 
# were already processed (meaning the non BRAF mutant were filtered out and differential analyses were already performed)

############ PANEL A ###############
#load the matrix for BRAF mutant with random WT
load(paste(dependecies_dir,"/Methylation/Methyl_BM_WT.rda",sep=""))
my.breaks <- c(seq(0, 0.2, length.out=10),seq(0.2, 0.4, length.out=1000),seq(0.4,1, length.out=10))
dev.off()
heatmap.2(as.matrix(Methyl_BM_WT),
          Rowv=TRUE,
          Colv=FALSE,
          dendrogram="none",
          scale="none",
          trace="none",
          col=colorRampPalette(brewer.pal(10,"PRGn")),
          ColSideColors=c(rep("yellow",23),rep("turquoise",23)),
          key=F)

######## PANEL B #########
load(paste(dependecies_dir,"/Methylation/Merge_Methyl.rda",sep=""))
#Figure without combat
clust_Meth<-nclust2(t(Merge_Methyl))
Merge_Methyl<-Merge_Methyl[clust_Meth$cclust$order,]

dev.off()
heatmap.2(as.matrix(Merge_Methyl[,c(6:7,25:30)]),
          Rowv=TRUE,
          Colv=FALSE,
          dendrogram="none",
          scale="none",
          trace="none",
          col=colorRampPalette(brewer.pal(10,"PRGn")),
          ColSideColors=c(rep("red",2),rep("blue",6)),
          key=F)

dev.off()
heatmap.2(as.matrix(Merge_Methyl[,c(1:5,8:24)]),
          Rowv=TRUE,
          Colv=FALSE,
          dendrogram="none",
          scale="none",
          trace="none",
          col=colorRampPalette(brewer.pal(10,"PRGn")),
          ColSideColors=c(rep("red",5),rep("blue",17)),
          key=F)

#################### DE and MLH1 for 27K ##################################

load(paste(dependecies_dir,"/Methylation/Meth27K.rda",sep=""))
#Extract TCGA patient names which are BM1 and BM2
TCGA_S1<-as.character(merge_clin$ID[which((merge_clin$Dataset=="TCGA")&(merge_clin$BM_subtype==1))])
TCGA_S2<-as.character(merge_clin$ID[which((merge_clin$Dataset=="TCGA")&(merge_clin$BM_subtype==2))])

#DE expression
vec<-c(0,0,1,1,1,1,1,1)
design<-model.matrix(~vec)
DE_Meth <- lmFit(object=Meth,design=design)
DE_Meth <- eBayes(DE_Meth)
DE_Meth_res <-topTable(DE_Meth, coef = 2, adjust = "fdr",number=nrow(Meth))
DE_Meth_res <-DE_Meth_res[which(DE_Meth_res$adj.P.Val < 0.05),]

#Matrix with only DE genes
Meth_Matrix_DE<-Meth[which(rownames(Meth) %in% rownames(DE_Meth_res)),]

#Clustering and ordered for gene similarity
clust_Meth<-nclust2(t(Meth_Matrix_DE))
Meth_Matrix_DE<-Meth_Matrix_DE[clust_Meth$cclust$order,]

#Reformatted for ggplot2 heatmap plotting
Melt_Meth_Matrix_DE<-melt(Meth_Matrix_DE)

##### PANEL D LEFT ######
Melt_Meth_Matrix_DE$value <- cut(Melt_Meth_Matrix_DE$value,breaks = c(seq(0,1,0.1)),right = TRUE)

dev.off()
heatmap.2(as.matrix(Meth_Matrix_DE),
          Rowv=TRUE,
          Colv=FALSE,
          dendrogram="none",
          scale="none",
          trace="none",
          col=colorRampPalette(brewer.pal(10,"PRGn")),
          ColSideColors=c(rep("red",2),rep("blue",6)),
          key=F)

##### PANEL C LEFT ######
MLH1<-Meth[grep("MLH1",rownames(Meth)),];MLH1<-MLH1[c(1:5),]
dev.off()
heatmap.2(as.matrix(MLH1),
          Rowv=TRUE,
          Colv=FALSE,
          dendrogram="none",
          scale="none",
          trace="none",
          col=colorRampPalette(brewer.pal(10,"PRGn")),
          ColSideColors=c("orange","darkblue")[as.numeric(factor(merge_clin$MSI_status[match(colnames(MLH1),merge_clin$ID)]))],
          key=F)



#################### DE and MLH1 for 450K ##################################

load(paste(dependecies_dir,"/Methylation/DE_Methy_450K.rda",sep=""))

#######PANEL D right########
my.breaks <- c(seq(0, 0.2, length.out=10),seq(0.2, 0.4, length.out=1000),seq(0.4,1, length.out=10))
dev.off()
heatmap.2(as.matrix(Meth_Matrix_DE2),
          Rowv=TRUE,
          Colv=FALSE,
          dendrogram="none",
          scale="none",
          trace="none",
          col=colorRampPalette(brewer.pal(10,"PRGn")),
          ColSideColors=c(rep("red",5),rep("blue",18)),
          key=F)

#######PANEL C right#########
load(paste(dependecies_dir,"/Methylation/MLH1_450K.rda",sep=""))
dev.off()
heatmap.2(as.matrix(MLH1_2[,1:23]),
          Rowv=TRUE,
          Colv=FALSE,
          dendrogram="none",
          scale="none",
          trace="none",
          col=colorRampPalette(brewer.pal(10,"PRGn")),
          ColSideColors=c("orange","green")[as.numeric(factor(merge_clin$MSI_status[match(substr(colnames(MLH1_2[,c(1:23)]),1,12),merge_clin$ID)]))],
          key=F)

rm(MLH1,MLH1_2,Melt_Meth_Matrix_DE,Merge_Methyl,Meth,Meth_Matrix_DE,Meth_Matrix_DE2,Methyl_BM_WT,
   DE_Meth,DE_Meth_res,design,vec,TCGA_S1,TCGA_S2,clust_Meth)




######################################################################################################################
#################################       Figure S10  and Table S2    ##################################################
######################################################################################################################

#### Determine the lambda of the generalized linear model using 100 loops of cross-validation
#### see the glmnet vignette for information. Since I know which subtype, I will use a logistic regression (binomial because two subtypes)

lambdaseq<-c(seq.log(0.307722456,0.003223749, 40),seq.log(0.3,0.00000000001, 60))

MSE <- NULL
glmobj<-list()
for (i in 1:100){
  cv <- cv.glmnet(t(combat_RNA), merge_clin$BM_subtype,lambda=lambdaseq, family = "binomial", type.measure = "class")  
  glmobj[[i]]<-cv
  MSE <- cbind(MSE, cv$cvm)
}
rownames(MSE) <- cv$lambda


#Extract the optimal lambda out of the 100 objects and take the average
lambda.min<-c()
for(i in 1:100){
  lambda.min <- c(lambda.min, glmobj[[i]]$lambda.1se)
}
lambda.min<-mean(lambda.min)

# Fit the generalized linear model
fit_glmnet <- glmnet(t(combat_RNA), merge_clin$BM_subtype, family = "binomial")

# Extract the genes with non-zeroed coefficient
Coef_glmnet<-coef(fit_glmnet,s=lambda.min)
Coef_glmnet<-Coef_glmnet[which(Coef_glmnet!=0),]
Coef_glmnet<-Coef_glmnet[-1]
names(Coef_glmnet)
length(names(Coef_glmnet))

####### Create Table S2
TableS2pos<-data.frame("Positive_Genes"=names(Coef_glmnet[which(Coef_glmnet>0)]),
                        "Coefficient_pos"=Coef_glmnet[which(Coef_glmnet>0)])
TableS2neg<-data.frame("Negative_Genes"=names(Coef_glmnet[which(Coef_glmnet<0)]),
                       "Coefficient_neg"=Coef_glmnet[which(Coef_glmnet<0)])
rm(TableS2neg,TableS2pos)

####### Plot Figure S9
#Compute SD

dev2<-c()
for(i in 1:nrow(MSE)){
  dev2<-sd(MSE[i,])
}

errbar(log(as.numeric(rownames(MSE)))[1:nrow(MSE)],
       rowMeans(MSE[1:nrow(MSE),]),
       rowMeans(MSE[1:nrow(MSE),])+dev2,
       rowMeans(MSE[1:nrow(MSE),])-dev2,
       xlab="log(lambda)",ylab="Misclassification error",
       pch=21,bg="red",col="black")
abline(v=log(lambda.min),col="blue",lwd=2)
text(log(lambda.min)+0.3,0.3,"Best lambda",srt=90,col="blue",cex=0.6)
mtext(c(paste(length(names(Coef_glmnet)))),
      side = 3, line = 0, outer = FALSE, at = log(mean(lambda.min)),col="blue")

rm(MSE,Coef_glmnet,cv,dev2,glmobj,lambdaseq)


######################################################################################################################
################################################   Table S6    #######################################################
######################################################################################################################

########### PREDICTION FOR CELL LINES #############
# The SANGER dataset is downloadable here: https://www.synapse.org/#!Synapse:syn2181096
# take this file -> sanger_rma_expression.tsv, paste it in the Dependencies/Cell_lines folder and load it
SANGER<-read.delim(paste(dependecies_dir,"/Cell_lines/sanger_rma_expression.tsv",sep=""),header=TRUE)
# The CCLE dataset is downloadable here: https://www.synapse.org/#!Synapse:syn2292133
# take this file -> CCLE_rmaProbesetsLevel.tsv, paste it in the Dependencies/Cell_lines folder and load it
CCLE<-read.delim(paste(dependecies_dir,"/Cell_lines/CCLE_rmaProbesetsLevel.tsv",sep=""),header=TRUE)
# The GSK dataset is downloadable here: https://www.synapse.org/#!Synapse:syn2181083
# take this file -> gsk_rma_expression.tsv, paste it in the Dependencies/Cell_lines folder and load it
GSK<-read.delim(paste(dependecies_dir,"/Cell_lines/gsk_rma_expression.tsv",sep=""),header=TRUE)

# Function to give the Matrix as input and return the predictionsfor BM subtype
ExtractPrediction <- function(Nameofdataset,Matrix){
  if(Nameofdataset=="Sanger"){Annot<-getGEO("GPL571")}
  if(Nameofdataset=="CCLE"){Annot<-getGEO("GPL570")}
  if(Nameofdataset=="GSK"){Annot<-getGEO("GPL570")}
  Annot<-Table(Annot)
  Matrix$var<-apply(Matrix,1,var)
  Matrix$Gene<-Annot$"Gene Symbol"[match(rownames(Matrix),Annot$ID)]
  Matrix$Gene<-strsplit2(Matrix$Gene,split="///")[,1]
  Matrix<-Matrix[order(Matrix$var,decreasing=TRUE),]
  Matrix<-Matrix[-which(duplicated(Matrix$Gene)==TRUE),]
  rownames(Matrix)<-Matrix$Gene
  Matrix<-Matrix[,-c((ncol(Matrix)-1),(ncol(Matrix)))]
  
  #Merge at the rownames level , adjust for batch effect and resplit
  Merge<-merge(combat_RNA,Matrix,by="row.names")
  rownames(Merge)<-Merge$Row.names;Merge<-Merge[,-1]
  Comb<-ComBat(dat=Merge, 
               batch=c(rep(1,ncol(combat_RNA)),rep(2,ncol(Matrix))),
               mod=NULL,
               par.prior=TRUE,
               prior.plots=FALSE)
  Combat_glm<-Comb[,c(1:ncol(combat_RNA))]
  Matrix<-Comb[,c((ncol(combat_RNA)+1):(ncol(combat_RNA)+ncol(Matrix)))]
  
  #Rerun the cross-validation because the data were slightly changed after batch correction and extract the prediction
  cvfit <- cv.glmnet(t(Combat_glm), merge_clin$BM_subtype, family = "binomial", type.measure = "class")
  PRED <- c(predict(cvfit, newx = t(Matrix), s = "lambda.min", type = "class"))
  names(PRED)<-colnames(Matrix)
  return(PRED)
}

#Table S6
Pred_Sanger<-ExtractPrediction("Sanger",SANGER)
Pred_CCLE<-ExtractPrediction("CCLE",CCLE)
Pred_GSK<-ExtractPrediction("GSK",GSK)

rm(SANGER,GSK,CCLE,ExtractPrediction,Pred_Sanger,Pred_CCLE,Pred_GSK)



######################################################################################################################
#################################       Figure S11  and Table S7    ##################################################
######################################################################################################################

####################################################################################

#Load the Sanger drug response data for the consistant cell lines
Response_Sanger<-read.csv(paste(dependecies_dir,"/Cell_lines/Drug_response_Sanger.csv",sep=""))

SW1116<-Response_Sanger[grep("SW1116",Response_Sanger$Cell.Line.Name),c(3,6)];SW1116<-SW1116[order(SW1116[,2],decreasing=TRUE),]
SW1417<-Response_Sanger[grep("SW1417",Response_Sanger$Cell.Line.Name),c(3,6)];SW1417<-SW1417[order(SW1417[,2],decreasing=TRUE),]
SW837<-Response_Sanger[grep("SW837",Response_Sanger$Cell.Line.Name),c(3,6)];SW837<-SW837[order(SW837[,2],decreasing=TRUE),]
LS1034<-Response_Sanger[grep("LS-1034",Response_Sanger$Cell.Line.Name),c(3,6)];LS1034<-LS1034[order(LS1034[,2],decreasing=TRUE),]
RKO<-Response_Sanger[grep("RKO",Response_Sanger$Cell.Line.Name),c(3,6)];RKO<-RKO[order(RKO[,2],decreasing=TRUE),]
HCT15<-Response_Sanger[grep("HCT-15",Response_Sanger$Cell.Line.Name),c(3,6)];HCT15<-HCT15[order(HCT15[,2],decreasing=TRUE),]
C2BBe1<-Response_Sanger[grep("C2BBe1",Response_Sanger$Cell.Line.Name),c(3,6)];C2BBe1<-C2BBe1[order(C2BBe1[,2],decreasing=TRUE),]
SW48<-Response_Sanger[grep("SW48",Response_Sanger$Cell.Line.Name),c(3,6)];SW48<-SW48[order(SW48[,2],decreasing=TRUE),]

#limit the analysis to the best 15 and worst 15 drugs for every cell lines
n<-15
DRUGS<-c(head(SW1116$Drug.ID,n),tail(SW1116$Drug.ID,n),
         head(SW1417$Drug.ID,n),tail(SW1417$Drug.ID,n),
         head(SW837$Drug.ID,n),tail(SW837$Drug.ID,n),
         head(LS1034$Drug.ID,n),tail(LS1034$Drug.ID,n),
         head(RKO$Drug.ID,n),tail(RKO$Drug.ID,n),
         head(HCT15$Drug.ID,n),tail(HCT15$Drug.ID,n),
         head(C2BBe1$Drug.ID,n),tail(C2BBe1$Drug.ID,n),
         head(SW48$Drug.ID,n),tail(SW48$Drug.ID,n))
DRUGS<-unique(DRUGS)

# Subset the data.frames with these drugs
SW1116_2<-SW1116[which(SW1116$Drug.ID %in% DRUGS),];SW1417_2<-SW1417[which(SW1417$Drug.ID %in% DRUGS),]
SW837_2<-SW837[which(SW837$Drug.ID %in% DRUGS),];LS1034_2<-LS1034[which(LS1034$Drug.ID %in% DRUGS),]
RKO_2<-RKO[which(RKO$Drug.ID %in% DRUGS),];HCT15_2<-HCT15[which(HCT15$Drug.ID %in% DRUGS),]
C2BBe1_2<-C2BBe1[which(C2BBe1$Drug.ID %in% DRUGS),];SW48_2<-SW48[which(SW48$Drug.ID %in% DRUGS),]

# Create a merge table
Merge4<-merge(SW1417_2,C2BBe1_2,by="Drug.ID",all=T);colnames(Merge4)<-c("Drug.ID","SW1417","C2BBe1")
Merge1<-merge(HCT15_2,LS1034_2,by="Drug.ID",all=T);colnames(Merge1)<-c("Drug.ID","HCT15","LS1034")
Merge2<-merge(SW1116_2,RKO_2,by="Drug.ID",all=T);colnames(Merge2)<-c("Drug.ID","SW1116","RKO")
Merge3<-merge(SW48_2,SW837_2,by="Drug.ID",all=T);colnames(Merge3)<-c("Drug.ID","SW48","SW837")
Merge41<-merge(Merge4,Merge1,by="Drug.ID",all=T);Merge23<-merge(Merge2,Merge3,by="Drug.ID",all=T)
Merge<-merge(Merge41,Merge23,by="Drug.ID",all=T);rm(Merge1,Merge2,Merge3,Merge4,Merge23,Merge41)

#Drug with the lowest AUC
Ave_act<-Merge
rownames(Ave_act)<-Ave_act$Drug.ID
Ave_act<-Ave_act[,-1]
idx<-match(rownames(Ave_act),Response_Sanger$Drug.ID)
Ave_act$Drug<-Response_Sanger$Drug.Name[idx]
Ave_act$Target<-Response_Sanger$Targets[idx]

#Differential expression
Matrix<-Merge[complete.cases(Merge),]
rownames(Matrix)<-Matrix$Drug.ID;Matrix<-Matrix[,-1]
vec<-c(0,0,1,1,1,1,1,1)
design<-model.matrix(~vec)
DE <- lmFit(object=Matrix,design=design)
DE <- eBayes(DE)
DE_res <-topTable(DE, coef = 2, adjust = "fdr",number=nrow(Matrix))
idx<-match(rownames(DE_res),Response_Sanger$Drug.ID)
DE_res$Drug<-Response_Sanger$Drug.Name[idx]
DE_res$Target<-Response_Sanger$Targets[idx]
rm(Matrix,design,vec)

######## Table S7 three first sheets
TableS7_sheet1<-Ave_act[order(apply(as.matrix(Ave_act[,c(1:2)]),1,function(x) mean(x)),decreasing=F),]
TableS7_sheet2<-Ave_act[order(apply(as.matrix(Ave_act[,c(3:8)]),1,function(x) mean(x)),decreasing=F),]
TableS7_sheet3<-DE_res

#Heatmap for the best drugs
DRUGS<-rownames(DE_res[1:20,])
SW1116_3<-SW1116[which(SW1116$Drug.ID %in% DRUGS),];SW1417_3<-SW1417[which(SW1417$Drug.ID %in% DRUGS),];SW837_3<-SW837[which(SW837$Drug.ID %in% DRUGS),]
LS1034_3<-LS1034[which(LS1034$Drug.ID %in% DRUGS),];RKO_3<-RKO[which(RKO$Drug.ID %in% DRUGS),];HCT15_3<-HCT15[which(HCT15$Drug.ID %in% DRUGS),]
C2BBe1_3<-C2BBe1[which(C2BBe1$Drug.ID %in% DRUGS),];SW48_3<-SW48[which(SW48$Drug.ID %in% DRUGS),]

Merge4<-merge(SW1417_3,C2BBe1_3,by="Drug.ID",all=F);colnames(Merge4)<-c("Drug.ID","SW1417","C2BBe1")
Merge1<-merge(HCT15_3,LS1034_3,by="Drug.ID",all=F);colnames(Merge1)<-c("Drug.ID","HCT15","LS1034")
Merge2<-merge(SW1116_3,RKO_3,by="Drug.ID",all=F);colnames(Merge2)<-c("Drug.ID","SW1116","RKO")
Merge3<-merge(SW48_3,SW837_3,by="Drug.ID",all=F);colnames(Merge3)<-c("Drug.ID","SW48","SW837")
Merge41<-merge(Merge4,Merge1,by="Drug.ID",all=F);Merge23<-merge(Merge2,Merge3,by="Drug.ID",all=F)
Merge<-merge(Merge41,Merge23,by="Drug.ID",all=F);rm(Merge1,Merge2,Merge3,Merge4,Merge23,Merge41)



Merge<-Merge[match(rownames(DE_res)[1:20],Merge$Drug.ID),]
Merge<-Merge[1:20,]
rownames(Merge)<-Merge$Drug.ID;Merge<-Merge[,-1]
rownames(Merge)<-Response_Sanger$Drug.Name[match(rownames(Merge),Response_Sanger$Drug.ID)]

#######  Figure S11 upper panel
heatmap.2(as.matrix(Merge),
          Rowv = F,
          Colv = F,
          col=colorRampPalette(brewer.pal(9,"Blues"))(1009),
          ColSideColors=c(rep("red",2),rep("blue",6)),
          trace="none",
          main="SANGER CELL LINE")

rm(Merge,SW1116,SW1116_2,SW1116_3,SW1417,SW1417_2,SW1417_3,SW48,SW48_2,SW48_3,SW837,SW837_2,SW837_3,C2BBe1,C2BBe1_2,C2BBe1_3,
   HCT15,HCT15_2,HCT15_3,LS1034,LS1034_2,LS1034_3,RKO,RKO_2,RKO_3,TableS7_sheet1,TableS7_sheet2,TableS7_sheet3,Ave_act,DE_res,
   Response_Sanger,DRUGS,DE)

######## CCLE ########

#Load the CCLE drug response data for the consistant cell lines
Response_CCLE<-read.csv(paste(dependecies_dir,"/Cell_lines/Drug_response_CCLE.csv",sep=""))

#Keep what's needed
CCLE<-Response_CCLE[,c(2,3,5)]
CCLE <- spread(CCLE, Primary.Cell.Line.Name, ActArea)
rownames(CCLE)<-CCLE$Compound;CCLE<-CCLE[,-1]
CCLE<-CCLE[,c(1,4,2,3,5)]

#Differential expression
Matrix<-CCLE[complete.cases(CCLE),]
vec<-c(0,0,1,1,1)
design<-model.matrix(~vec)
DE <- lmFit(object=Matrix,design=design)
DE <- eBayes(DE)
DE_res <-topTable(DE, coef = 2, adjust = "fdr",number=nrow(Matrix))
DE_res$Drug <- rownames(DE_res)
DE_res$Target <- Response_CCLE$Target[match(rownames(DE_res),Response_CCLE$Compound)]
CCLE<-CCLE[match(rownames(DE_res),rownames(CCLE)),]
rm(Matrix,vec,design)

######## Table S7 three last sheets
TableS7_sheet4<-CCLE[order(apply(as.matrix(CCLE[,c(1:2)]),1,function(x) mean(x)),decreasing=T),]
TableS7_sheet5<-CCLE[order(apply(as.matrix(CCLE[,c(3:5)]),1,function(x) mean(x)),decreasing=T),]
TableS7_sheet6<-DE_res

#######  Figure S10 lower panel
my.breaks <- c(seq(0, 2, length.out=10),seq(2.01, 7.2, length.out=4))
heatmap.2(as.matrix(CCLE),
          Rowv = FALSE,
          Colv = FALSE,
          col=colorRampPalette(brewer.pal(9,"Blues"))(13),
          breaks=my.breaks,
          ColSideColors=c("red","red","blue","blue","blue"),
          trace="none")

rm(CCLE,DE_res,Response_CCLE,TableS7_sheet4,TableS7_sheet5,TableS7_sheet6,DE)

######################################################################################################################
###########################################         TABLE S3          ################################################
######################################################################################################################
Fisher.Table<-data.frame("Factor"=c("MSI","Location","Gender","Dataset","Stage"),
                         "Stats"=c(fisher.test(merge_clin$BM_subtype,merge_clin$MSI_status)$p.value,
                                   fisher.test(merge_clin$BM_subtype,merge_clin$Site)$p.value,
                                   fisher.test(merge_clin$BM_subtype,merge_clin$Sex)$p.value,
                                   fisher.test(merge_clin$BM_subtype,merge_clin$Source)$p.value,
                                   fisher.test(merge_clin$BM_subtype,merge_clin$Stage)$p.value))

# n=6 because PI3K test was orignally performed
Fisher.Table$Stats<-p.adjust(Fisher.Table$Stats,method="bonferroni",n=(length(Fisher.Table$Stats)+1))
rm(Fisher.Table)

######################################################################################################################
###########################################         TABLE S4          ################################################
######################################################################################################################

#Genes Specific for Subtype
SUBTYPETABLE<-Regr_table[setdiff(rownames(Regr_table[which(Regr_table$Subtype_pval<pval),]),
                                 rownames(Regr_table[which((Regr_table$Subtype_pval<pval)&
                                                             (Regr_table$MSI_pval<pval)&
                                                             (Regr_table$Site_pval>pval)&
                                                             (Regr_table$Sex_pval>pval)),])),1:3]
SUBTYPETABLE<-SUBTYPETABLE[order(SUBTYPETABLE$Subtype_pval,decreasing=FALSE),]

#Genes Specific for MSI
MSITABLE<-Regr_table[setdiff(rownames(Regr_table[which(Regr_table$MSI_pval<pval),]),
                             rownames(Regr_table[which((Regr_table$Subtype_pval<pval)&
                                                         (Regr_table$MSI_pval<pval)&
                                                         (Regr_table$Site_pval>pval)&
                                                         (Regr_table$Sex_pval>pval)),])),5:7]
MSITABLE<-MSITABLE[order(MSITABLE$MSI_pval,decreasing=FALSE),]

#Genes Specific for Gender
GENDERTABLE<-Regr_table[rownames(Regr_table[which(Regr_table$Sex_pval<pval),]),13:15]
GENDERTABLE<-GENDERTABLE[order(GENDERTABLE$Sex_pval,decreasing=FALSE),]

#Uncomment if you want to save as csv
# write.csv(SUBTYPETABLE,file="SubtypeGenes.csv")
# write.csv(MSITABLE,file="MSIGenes.csv")
# write.csv(GENDERTABLE,file="GenderGenes.csv")
rm(SUBTYPETABLE,GENDERTABLE,MSITABLE)

